@@ -3,36 +3,53 @@ package ReRe::Server;
 
 use Moose;
 use Redis;
+use ReRe::Config;
 
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
+
+has file => (
+    is  => 'rw',
+    isa => 'Str'
+);
+
+around 'file' => sub {
+    my $orig = shift;
+    my $self = shift;
+    return $self->$orig() unless @_;
+    my ($file) = shift;
+    warn $file;
+    my $config = ReRe::Config->new( { file => $file } );
+    $self->server( $config->{server}{host} ) if defined( $config->{server}{host} );
+    $self->port( $config->{server}{port} )   if defined( $config->{server}{port} );
+};
 
 has server => (
-    is => 'rw',
-    isa => 'Str',
+    is      => 'rw',
+    isa     => 'Str',
     default => '127.0.0.1'
 );
 
 has port => (
-    is => 'rw',
-    isa => 'Int',
+    is      => 'rw',
+    isa     => 'Int',
     default => '6379'
 );
 
 has conn => (
-    is => 'rw',
-    isa => 'Object',
-    lazy => 1,
+    is      => 'rw',
+    isa     => 'Object',
+    lazy    => 1,
     default => sub {
         my $self = shift;
-        my $host = join(':', $self->server, $self->port);
-        return Redis->new(server => $host);
+        my $host = join( ':', $self->server, $self->port );
+        return Redis->new( server => $host );
     }
 );
 
 
 
 sub has_method {
-    my ($self, $method) = @_;
+    my ( $self, $method ) = @_;
     return $self->conn->can($method);
 }
 
@@ -55,7 +72,7 @@ ReRe::Server
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 METHODS
 
